@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ NoteDisplayAttributeTest::NoteDisplayAttributeTest(QObject *parent)
 {
 }
 
-NoteDisplayAttributeTest::~NoteDisplayAttributeTest()
-{
-}
+NoteDisplayAttributeTest::~NoteDisplayAttributeTest() = default;
 
 void NoteDisplayAttributeTest::shouldHaveDefaultValue()
 {
